==> idwise_flutter_sdk-1.0.1-rc.2.tar.gz: lib/idwise_flutter.dart <==
import 'idwise_flutter_platform_interface.dart';

class IDWise {
  Future<String?> getPlatformVersion() {
    return IdwiseFlutterPlatform.instance.getPlatformVersion();
  }

  static Future<void> initialize(String clientKey, IDWiseSDKTheme theme,
      {required onError, onSuccess}) async {
    IdwiseFlutterPlatform.instance
        .initialize(clientKey, theme, onError: onError);
  }

  static void startJourney(String journeyDefinitionId, String referenceNo,
      String locale, IDWiseSDKJourneyCallbacks journeyCallbacks) {
    IdwiseFlutterPlatform.instance.startJourney(
        journeyDefinitionId, referenceNo, locale, journeyCallbacks);
  }

  static void startDynamicJourney(
      String journeyDefinitionId,
      String referenceNo,
      String locale,
      IDWiseSDKJourneyCallbacks journeyCallbacks,
      IDWiseSDKStepCallbacks stepCallbacks) {
    IdwiseFlutterPlatform.instance.startDynamicJourney(journeyDefinitionId,
        referenceNo, locale, journeyCallbacks, stepCallbacks);
  }

  static void resumeDynamicJourney(
      String journeyDefinitionId,
      String journeyId,
      String locale,
      IDWiseSDKJourneyCallbacks journeyCallbacks,
      IDWiseSDKStepCallbacks stepCallbacks) {
    IdwiseFlutterPlatform.instance.resumeDynamicJourney(journeyDefinitionId,
        journeyId, locale, journeyCallbacks, stepCallbacks);
  }

  static void getJourneySummary({required onJourneySummary}) {
    IdwiseFlutterPlatform.instance
        .getJourneySummary(journeySummary: onJourneySummary);
  }

  static void startStep(String stepId) {
    IdwiseFlutterPlatform.instance.startStep(stepId);
  }

  static void skipStep(String stepId) {
    IdwiseFlutterPlatform.instance.skipStep(stepId);
  }

  static void finishDynamicJourney() {
    IdwiseFlutterPlatform.instance.finishDynamicJourney();
  }

  static void unloadSDK() {
    IdwiseFlutterPlatform.instance.unloadSDK();
  }
}

enum IDWiseSDKTheme { LIGHT, DARK, SYSTEM_DEFAULT }

class IDWiseSDKJourneyCallbacks {
  IDWiseSDKJourneyCallbacks(
      {required Function(dynamic) this.onError,
      required void Function(dynamic) this.onJourneyCancelled,
      required void Function(dynamic) this.onJourneyCompleted,
      required void Function(dynamic) this.onJourneyResumed,
      required void Function(dynamic) this.onJourneyStarted});

  Function onJourneyStarted;
  Function onJourneyCompleted;
  Function onJourneyResumed;
  Function onJourneyCancelled;
  Function onError;
}

class IDWiseSDKStepCallbacks {
  IDWiseSDKStepCallbacks(
      {required void Function(dynamic) this.onStepCaptured,
      required void Function(dynamic) this.onStepResult,
      required void Function(dynamic) this.onStepSkipped,
      required void Function(dynamic) this.onStepCancelled});

  Function onStepCaptured;
  Function onStepResult;
  Function onStepSkipped;
  Function onStepCancelled;
}

==> idwise_flutter_sdk-4.5.5.tar.gz: lib/idwise_flutter.dart <==
import 'idwise_flutter_platform_interface.dart';

class IDWise {
  Future<String?> getPlatformVersion() {
    return IdwiseFlutterPlatform.instance.getPlatformVersion();
  }

  static Future<void> initialize(String clientKey, IDWiseSDKTheme theme,
      {required onError, onSuccess}) async {
    IdwiseFlutterPlatform.instance
        .initialize(clientKey, theme, onError: onError);
  }

  static void startJourney(String journeyDefinitionId, String referenceNo,
      String locale, IDWiseSDKJourneyCallbacks journeyCallbacks) {
    IdwiseFlutterPlatform.instance.startJourney(
        journeyDefinitionId, referenceNo, locale, journeyCallbacks);
  }

  static void startDynamicJourney(
      String journeyDefinitionId,
      String referenceNo,
      String locale,
      IDWiseSDKJourneyCallbacks journeyCallbacks,
      IDWiseSDKStepCallbacks stepCallbacks) {
    IdwiseFlutterPlatform.instance.startDynamicJourney(journeyDefinitionId,
        referenceNo, locale, journeyCallbacks, stepCallbacks);
  }

  static void resumeDynamicJourney(
      String journeyDefinitionId,
      String journeyId,
      String locale,
      IDWiseSDKJourneyCallbacks journeyCallbacks,
      IDWiseSDKStepCallbacks stepCallbacks) {
    IdwiseFlutterPlatform.instance.resumeDynamicJourney(journeyDefinitionId,
        journeyId, locale, journeyCallbacks, stepCallbacks);
  }

  static void getJourneySummary(String journeyId, {required onJourneySummary}) {
    IdwiseFlutterPlatform.instance
        .getJourneySummary(journeyId, journeySummary: onJourneySummary);
  }

  static void startStep(String stepId) {
    IdwiseFlutterPlatform.instance.startStep(stepId);
  }

  static void unloadSDK() {
    IdwiseFlutterPlatform.instance.unloadSDK();
  }
}

enum IDWiseSDKTheme { LIGHT, DARK, SYSTEM_DEFAULT }

class IDWiseSDKJourneyCallbacks {
  IDWiseSDKJourneyCallbacks(
      {required Function(dynamic) this.onError,
      required void Function(dynamic) this.onJourneyCancelled,
      required void Function(dynamic) this.onJourneyCompleted,
      required void Function(dynamic) this.onJourneyResumed,
      required void Function(dynamic) this.onJourneyStarted});

  Function onJourneyStarted;
  Function onJourneyCompleted;
  Function onJourneyResumed;
  Function onJourneyCancelled;
  Function onError;
}

class IDWiseSDKStepCallbacks {
  IDWiseSDKStepCallbacks(
      {required void Function(dynamic) this.onStepCaptured,
      required void Function(dynamic) this.onStepResult,
      required void Function(dynamic) this.onStepCancelled});

  Function onStepCaptured;
  Function onStepResult;
  Function onStepCancelled;
}
